#===============================================================================
# Ttulo   : Anlise quantitativa de dados - AQE
# Autor    : Jos Cludio Faria/UESC/DCET
# Data     : 2023-07-10 17:11:42
# Objetivos:
#===============================================================================
# a) Apresentar os recursos bsicos do R para anlise de regresso
# b) Fundamentao em regresso linear
# c) ANOVA completa de AQE com repeties
#===============================================================================

#===============================================================================
# NFASE NAS FUNES DO R PARA MODELOS LINEARES (lm) - USO ROTINEIRO
#===============================================================================
# Gerando dados - experimento virtual
# x: varivel independente (regressor/tratamento)
# y: varivel dependente (fator resposta)

#================================
#.. Modelando um experimento
#================================
set.seed(20181000)
x <- sort(rep(1:5,
              6))  # 5 tratamentos e 6 repeties

r <- rep(1:6,
         5)        # 6 repeties

y <- 2 + 1 * x + rnorm(30,
                       mean=0,
                       sd=1)

# Modelando uma varivel de resposta (y), segundo um modelo linear
# pr-concebido (y = 2 + 1*x)
# com uma pertubao (erro experimental) intencional

# Armazenando num data.frame
(dad  <- data.frame(x, 
                    r, 
                    y))

# Visualizando os dados
with(dad,
     plot(y ~ factor(x),
          ylim=c(0, 10)))

# Observar que x visualmente influencia y!

#================================
#.. Analisando o experimento
#================================
# ANOVA preliminar segundo delineamento inteiramente casualizado - DIC
av <- aov(y ~ factor(x),
          data=dad)

summary(av)              

# Pode concluir que o efeito dos tratamentos (nveis de x)  significativo.
# Como os tratamentos so quantitativos, a anlise deve ser, necessariamente,
# conduzida via anlise de regresso.

# Ou seja, no se pode realizar testes de comparao de mdias mltiplas,
# nem anlise de contrastes, para comparar os nveis de x entre si.

#  necessrio estudar se  possvel estabelecer uma relao
# funcional de y em funo de x. Em outras palavras, ajustar um modelo
# matemtico que permita a predio de y a medida que x varia no intervalo
# considerado, alm de testar estatisticamente a validade do modelo.

# Calculando as mdias de tratamentos
(dad_m <- aggregate(y ~ x,
                    data=dad,
                    mean))

# Ajustando modelo linear e visualizando os resultados
with(dad_m,
     plot(y ~ x,
          ylab='m(y)',
          ylim=c(0, 10),
          pch=19,
          col='blue'))

#===============================================================================
#.. Opes de modelos a serem ajustados
#===============================================================================
#... Polinmio de 1 grau
reg <- lm(y ~ x,
          data=dad_m)

#reg <- lm(y ~ 0 + x,   # Forando passar pela origem
#          data=dad_m)

#... Polinmio de 2 grau
#reg <- lm(y ~ x + I(x^2),
#          data=dad_m)

#reg <- lm(y ~ 0 + x + I(x^2),  # Forando passar pela origem
#         data=dad_m)
#===============================================================================

(sm_reg <- summary(reg))

(ANOVA_reg <- anova(reg))

# A partir da ANOVAreg  necessrio completar o quadro abaixo
# de acordo com o modelo ajustado (linear ou quadrtico) para as concluses finais.

# ANOVA FINAL
#----------------------------------------------------------
#            Df  Sum Sq  Mean Sq   F value   Pr(>F)
#----------------------------------------------------------
#Tra        (4)  (55.72)  13.929   17.23     6.66e-07 ***
#----------------------------------------------------------
#DReg         ?      ?       ?        ?           ?
#DIreg        ?      ?       ?        ?           ?
#----------------------------------------------------------
#Residuals   25   20.22    0.809

#--------------------------------------------------------------------------------------------------------------------------#
# A partir do quadro acima  que so feitas as concluses finais e definio final do modelo a ser adotado!
# Para completar o quadro da ANOVA final, basta multiplicar a soma do quadrado dos desvio do devido a regresso (x)
# e do devido ao independente da regresso (Residuals), ambos obtidos anteriormente (ANOVAreg), pelo nmero de
# repeties (aplicao do Teorema do Limite Central) para obter as somas de quadrados de quadrados do Dreg e DIreg.

#--------------------------------------------------------
#.. Modelo: polinmio de grau I com intercepto
#--------------------------------------------------------
# Clculo dos valores necessrios para preencher a ANOVA FINAL
# Soma de quadrados
ANOVA_reg
(SQD_reg  <- ANOVA_reg[1,2] * 6)
(SQD_ireg <- ANOVA_reg[2,2] * 6)

# Graus de liberdade
(Df_reg  <- ANOVA_reg[1,1])
(Df_ireg <- ANOVA_reg[2,1])

# Quadrados mdios
(QM_reg  <- SQD_reg  / Df_reg)
(QM_ireg <- SQD_ireg / Df_ireg)

# Valores da estatstica F
(F_reg  <- QM_reg  / 0.809)  # 0.809  o erro experimental
(F_ireg <- QM_ireg / 0.809)

# Probabilidades associadas aos valores F
(Preg  <- pf(F_reg,
             1,
             25,
             lower=F))   # Significativo

(Pireg <- pf(F_ireg,
             3,
             25,
             lower=F))  # No significativo!

#... ANOVA FINAL - Polinmio grau I com intercepto
# ----------------------------------------------------------
#             Df  Sum Sq  Mean Sq   F value   Pr(>F)
# ----------------------------------------------------------
# Tra        (4)  (55.72)  13.929   17.23     6.66e-07 ***
# ----------------------------------------------------------
# DReg        1    50.85   50.848   62.85     2.769996e-08 ***
# DIreg       3     4.87    1.623    2.01     0.1689995    ns    <--------- Observar!
# ----------------------------------------------------------
# Residuals   25   20.22    0.809
#.. Concluso final: opo pelo modelo linear grau I

#---------------------------------------------------------
#.. Apresentao grfica final: Polinmio grau I
#---------------------------------------------------------
# Grfico
with(dad_m,
     plot(y ~ x,
          ylab='Y',
          xlab='X',
          ylim=c(0, 10),
          pch=19,
          col='darkgreen'))

# Modelo ajustado
reg <- lm(y ~ x,
          data=dad_m)

lines(fitted(reg) ~ dad_m$x,
      col='red')

#--------------------------------------------------------
# Texto no grfico
#--------------------------------------------------------
text(substitute(hat(Y) == a + b*X,
                list(a=round(reg$coefficients[1],
                             4),
                     b=round(reg$coefficients[2],
                             4))),
     x=4,
     y=3)

# Coeficiente de determinao
(sm_reg <- summary(reg))
cd <- substitute(r^2 == r2,
                 list(r2=round(sm_reg$r.squared,
                               4)))

text(cd,
     x=4,
     y=2)
#--------------------------------------------------------------------------------------------------------------------------#
#. Pode finalizar a anlise aqui!
#--------------------------------------------------------------------------------------------------------------------------#

#. Aprendizado: polinmio grau II e III
#-----------------------------------------------
#.. Modelo: polinmio grau II com intercepto
#-----------------------------------------------
reg <- lm(y ~ x + I(x^2),
          data=dad_m)

(sm_reg <- summary(reg))

(ANOVA_reg <- anova(reg))

# Soma de quadrados
ANOVA_reg
(SQD_reg  <- sum(ANOVA_reg[1,2],
                 ANOVA_reg[2,2]) * 6)
(SQD_ireg <- ANOVA_reg[3,2] * 6)

# Graus de liberdade
(Df_reg  <- sum(ANOVA_reg[1,1],
                ANOVA_reg[2,1]))
(Df_ireg <- ANOVA_reg[3,1])

# Quadrados mdios
(QM_reg  <- SQD_reg  / Df_reg)
(QM_ireg <- SQD_ireg / Df_ireg)

# Valores da estatstica F
(F_reg  <- QM_reg  / 0.809)  # 0.809  o erro experimental
(F_ireg <- QM_ireg / 0.809)

# Probabilidades associadas aos valores F
(Preg  <- pf(F_reg,
             2,
             25,
             lower=F))   # Significativo

(Pireg <- pf(F_ireg,
             2,
             25,
             lower=F))  # No significativo!

#... ANOVA FINAL - Polinmio grau II com intercepto
# ----------------------------------------------------------
#             Df  Sum Sq  Mean Sq   F value   Pr(>F)
# ----------------------------------------------------------
# Tra        (4)  (55.72)  13.929   17.23     6.66e-07 ***
# ----------------------------------------------------------
# DReg        2    53.03   26.513   32.77     5.792956e-06 ***
# DIreg       2     2.69    1.345   1.66      0.2090218    ns    <--------- Observar!
# ----------------------------------------------------------
# Residuals  25    20.22    0.809
#--------------------------------------------------------------------------------------------------------------------------#
#.. Concluso final: opo pelo modelo linear de grau I

# Plotando as mdias Polinmio de grau II
with(dad_m,
     plot(y ~ x,
          ylab='m(y)',
          ylim=c(0, 10),
          pch=19,
          col='blue'))

# Predizer valores y a partir de valores x
(y_pred <- predict(reg,
                   new=data.frame(x=c(1.5, 2.5, 3.5, 4.5))))

# Visualizar mdias e modelo linear ajustado
lines(spline(fitted(reg) ~ dad_m$x,
             n=1e3),
      col='red')

# Visualizar valores preditos
points(x=c(1.5, 2.5, 3.5, 4.5),
       y=y_pred,
       pch=19,
       col='red')


#--------------------------------------------------------------------
#.. Apresentao grfica: polinmio grau II
#--------------------------------------------------------------------
# Grfico
with(dad_m,
     plot(y ~ x,
          ylab='Y',
          xlab='X',
          ylim=c(0, 10),
          pch=19,
          col='darkgreen'))

# Modelo ajustado
reg <- lm(y ~ x + I(x^2),
          data=dad_m)

lines(spline(fitted(reg) ~ dad_m$x,
             n=1e3),
      col='red')

text(substitute(hat(Y) == a + b*X - c*X^2,
                list(a=round(reg$coefficients[1],
                             4),
                     b=round(reg$coefficients[2],
                             4),
                     c=round(abs(reg$coefficients[3]),
                             4))),
     x=2.5,
     y=9)

# Coeficiente de determinao
(sm_reg <- summary(reg))
cd <- substitute(r^2 == r2,
                 list(r2=round(sm_reg$r.squared, 
                               4)))

text(cd,
     x=2.5,
     y=8)

#--------------------------------------------------------------------
#.. Apresentao grfica: polinmio grau III
#--------------------------------------------------------------------
# hipottico; apenas para mostrar como escrever as
# informaes importantes na apresentao grfica final
#--------------------------------------------------------
text(expression(hat(Y) == 2 +
                          1.4*X -
                          0.12*X^2 +
                          0.0019*X^3),
     x=2,
     y=2,
     col='red')

text(expression(r^2 == 0.98),
     x=2,
     y=1,
     col='red')
